@@ -2,16 +2,43 @@ use 5.008;
 use strict;
 use warnings;
 
-package Dist::Zilla::Plugin::InstallGuide;
-
+package Dist::Zilla::Plugin::InstallGuide; # git description: v1.200010-1-g506c085
 # ABSTRACT: Build an INSTALL file
-our $VERSION = '1.200010'; # VERSION
+
+our $VERSION = '1.200011';
+
 use Moose;
 with 'Dist::Zilla::Role::FileGatherer';
 with 'Dist::Zilla::Role::TextTemplate';
 with 'Dist::Zilla::Role::FileMunger';
 use List::Util 1.33 qw(first any);
+use namespace::autoclean;
 
+#pod =head1 SYNOPSIS
+#pod
+#pod In C<dist.ini>:
+#pod
+#pod     [InstallGuide]
+#pod
+#pod =begin :prelude
+#pod
+#pod =for test_synopsis BEGIN { die "SKIP: synopsis isn't perl code" }
+#pod
+#pod =end :prelude
+#pod
+#pod =head1 DESCRIPTION
+#pod
+#pod This plugin adds a very simple F<INSTALL> file to the distribution, telling
+#pod the user how to install this distribution.
+#pod
+#pod You should use this plugin in your L<Dist::Zilla> configuration after
+#pod C<[MakeMaker]> or C<[ModuleBuild]> so that it can determine what kind of
+#pod distribution you are building and which installation instructions are
+#pod appropriate.
+#pod
+#pod =head1 METHODS
+#pod
+#pod =cut
 
 has template => (is => 'ro', isa => 'Str', default => <<'END_TEXT');
 This is the Perl distribution {{ $dist->name }}.
@@ -109,6 +136,11 @@ https://metacpan.org/pod/local::lib
 END_TEXT
 );
 
+#pod =head2 gather_files
+#pod
+#pod Creates the F<INSTALL> file.
+#pod
+#pod =cut
 
 sub gather_files {
     my $self = shift;
@@ -123,6 +155,11 @@ sub gather_files {
     return;
 }
 
+#pod =head2 munge_files
+#pod
+#pod Inserts the appropriate installation instructions into F<INSTALL>.
+#pod
+#pod =cut
 
 sub munge_files {
     my $self = shift;
@@ -182,7 +219,7 @@ Dist::Zilla::Plugin::InstallGuide - Build an INSTALL file
 
 =head1 VERSION
 
-version 1.200010
+version 1.200011
 
 =for test_synopsis BEGIN { die "SKIP: synopsis isn't perl code" }
 
@@ -212,21 +249,16 @@ Creates the F<INSTALL> file.
 
 Inserts the appropriate installation instructions into F<INSTALL>.
 
-=head1 AVAILABILITY
+=head1 SUPPORT
 
-The latest version of this module is available from the Comprehensive Perl
-Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
-site near you, or see L<https://metacpan.org/module/Dist::Zilla::Plugin::InstallGuide/>.
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-InstallGuide>
+(or L<bug-Dist-Zilla-Plugin-InstallGuide@rt.cpan.org|mailto:bug-Dist-Zilla-Plugin-InstallGuide@rt.cpan.org>).
 
-=head1 SOURCE
+There is also a mailing list available for users of this distribution, at
+L<http://dzil.org/#mailing-list>.
 
-The development version is on github at L<https://github.com/doherty/Dist-Zilla-Plugin-InstallGuide>
-and may be cloned from L<git://github.com/doherty/Dist-Zilla-Plugin-InstallGuide.git>
-
-=head1 BUGS AND LIMITATIONS
-
-You can make new bug reports, and view existing ones, through the
-web interface at L<https://github.com/doherty/Dist-Zilla-Plugin-InstallGuide/issues>.
+There is also an irc channel available for users of this distribution, at
+L<C<#distzilla> on C<irc.perl.org>|irc://irc.perl.org/#distzilla>.
 
 =head1 AUTHORS
 
@@ -242,6 +274,46 @@ Mike Doherty <doherty@cpan.org>
 
 =back
 
+=head1 CONTRIBUTORS
+
+=for stopwords Mike Doherty Karen Etheridge Marcel Gruenauer jonasbn Dan Book Dave Rolsky Apocalypse
+
+=over 4
+
+=item *
+
+Mike Doherty <mike@mikedoherty.ca>
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Marcel Gruenauer <hanekomu@gmail.com>
+
+=item *
+
+jonasbn <jonasbn@gmail.com>
+
+=item *
+
+Mike Doherty <doherty@cs.dal.ca>
+
+=item *
+
+Dan Book <grinnz@gmail.com>
+
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=item *
+
+Apocalypse <APOCAL@cpan.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2010 by Marcel Grünauer <marcel@cpan.org>.
